pub enum MatchOp {
Eq,
Ne,
ReMatch,
ReNotMatch,
}Expand description
Matcher operator label, as written in config and over the API.
Variants
Eq
=: the resolved value equals value.
Ne
!=: the resolved value does not equal value.
ReMatch
=~: the resolved value matches the value regex.
ReNotMatch
!~: the resolved value does not match the value regex.