pub struct RiskEntityView {
pub entity_type: String,
pub entity_value: String,
pub score: i64,
pub tactic_count: u64,
pub source_count: u64,
pub result_count: u64,
pub window_start: i64,
pub window_end: i64,
pub last_fired: Option<i64>,
}Expand description
A read-only view of one open entity, served by GET /api/v1/risk.
Fields
entity_type: StringThe risk-object type.
entity_value: StringThe entity value.
score: i64The accumulated risk score over the window.
tactic_count: u64The distinct ATT&CK tactic count over the window.
source_count: u64The distinct contributing-source count over the window.
result_count: u64Number of contributing detections retained over the window.
window_start: i64First and last contributing-detection timestamps (unix seconds).
window_end: i64last_fired: Option<i64>When this entity last fired an incident, if ever (unix seconds).