Module file

Module file 

File source resolver: reads data from local files.

Functions

parse_data
Parse raw string data according to the specified format.
resolve_file
Resolve a file source by reading and parsing the file at path.