pub fn parse_data(raw: &str, format: DataFormat) -> Result<Value, SourceError>Expand description
Parse raw string data according to the specified format.
pub fn parse_data(raw: &str, format: DataFormat) -> Result<Value, SourceError>Parse raw string data according to the specified format.