Module include

Module include 

Include expansion for dynamic pipelines.

Expands Transformation::Include { template } directives by fetching the referenced source and parsing it as a list of transformation YAML objects, then splicing them into the transformations list.

Functions

expand_includes
Expand all Include transformations in a pipeline.