pub fn auto_detect(
line: &str,
syslog_config: &SyslogConfig,
) -> EventInputDecodedExpand description
Auto-detect the format of a single line and parse it.
The syslog_config is used when the syslog path is selected (e.g. to
honor --syslog-tz even in auto-detect mode).