Module processor
rsigma_
runtime
0.12.0
Module processor
Module Items
Structs
Type Aliases
In crate rsigma_
runtime
rsigma_runtime
Module
processor
Structs

LogProcessor
Thread-safe handle to the engine, swappable atomically for hot-reload.
Type Aliases

Event
Filter
Closure that extracts multiple payloads from a single JSON value.