File source resolver: reads data from local files.
Functions
- parse_
data - Parse raw string data according to the specified format.
- resolve_
file - Resolve a file source by reading and parsing the file at
path.
File source resolver: reads data from local files.
path.