pub struct TemplateExpander;Expand description
Expands ${source.*} template references in a pipeline using resolved source data.
Implementations
Sourceimpl TemplateExpander
impl TemplateExpander
Sourcepub fn expand(
pipeline: &Pipeline,
resolved: &HashMap<String, Value>,
) -> Pipeline
pub fn expand( pipeline: &Pipeline, resolved: &HashMap<String, Value>, ) -> Pipeline
Expand all ${source.*} references in the pipeline’s vars and return an updated pipeline.
The pipeline’s vars values are expanded by replacing template expressions
with data from the resolved map. Transformation fields containing templates
are left in place (they are handled at apply-time, not here) since transformations
use typed structures rather than raw strings.